@@ -201,7 +201,7 @@ class CAM(object):
                 self._hset("task_finished", task['task_id'], task)
                 self._redis.hdel("task_running", task['task_id'])
             # If my runing task was set to DISCONNECTED by others
-            if task['task_id'] == self._node_status['task']['task_id']:
+            if 'task_id' in self._node_status['task'] and task['task_id'] == self._node_status['task']['task_id']:
                 foundMyTask = True
         if not foundMyTask and self._node_status['node_status'] == "RUNNING":
             self._hset('task_running', self._node_status['task']['task_id'], self._node_status['task'])
